const db = require('../config/db');
const { comparePassword, hashPassword } = require('../util/hash');

async function findUserByCustomerNo(customerNo) {
  const result = await db.query('SELECT * FROM users WHERE customer_no = $1', [
    customerNo,
  ]);
  return result.rows[0];
}

async function validateUser(customerNo, password) {
  const user = await findUserByCustomerNo(customerNo);
  if (!user) return null;
  const isMatch = await comparePassword(password, user.password_hash);
  return isMatch ? user : null;
}

async function validateTpin(customerNo, tpin) {
  const user = await findUserByCustomerNo(customerNo);
  if (!user?.tpin) return null;
  const isMatch = await comparePassword(tpin, user.tpin);
  return isMatch;
}

async function setTpin(customerNo, tpin) {
  const hashedTpin = await hashPassword(tpin);
  try {
    await db.query('UPDATE users SET tpin = $1 WHERE customer_no = $2', [
      hashedTpin,
      customerNo,
    ]);
  } catch (error) {
    throw new Error(
      `error occured while while setting new tpin ${error.message}`
    );
  }
}

module.exports = { validateUser, findUserByCustomerNo, setTpin, validateTpin };
